==> cdktf-cdktf-provider-gitlab-6.0.1.tar.gz: package/docs/API.go.md <==
# Submodules <a name="Submodules" id="submodules"></a>

The following submodules are available:
- [applicationSettings](./applicationSettings.go.md)
- [branch](./branch.go.md)
- [branchProtection](./branchProtection.go.md)
- [clusterAgent](./clusterAgent.go.md)
- [clusterAgentToken](./clusterAgentToken.go.md)
- [dataGitlabBranch](./dataGitlabBranch.go.md)
- [dataGitlabClusterAgent](./dataGitlabClusterAgent.go.md)
- [dataGitlabClusterAgents](./dataGitlabClusterAgents.go.md)
- [dataGitlabCurrentUser](./dataGitlabCurrentUser.go.md)
- [dataGitlabGroup](./dataGitlabGroup.go.md)
- [dataGitlabGroupHook](./dataGitlabGroupHook.go.md)
- [dataGitlabGroupHooks](./dataGitlabGroupHooks.go.md)
- [dataGitlabGroupMembership](./dataGitlabGroupMembership.go.md)
- [dataGitlabGroupSubgroups](./dataGitlabGroupSubgroups.go.md)
- [dataGitlabGroupVariable](./dataGitlabGroupVariable.go.md)
- [dataGitlabGroupVariables](./dataGitlabGroupVariables.go.md)
- [dataGitlabGroups](./dataGitlabGroups.go.md)
- [dataGitlabInstanceDeployKeys](./dataGitlabInstanceDeployKeys.go.md)
- [dataGitlabInstanceVariable](./dataGitlabInstanceVariable.go.md)
- [dataGitlabInstanceVariables](./dataGitlabInstanceVariables.go.md)
- [dataGitlabMetadata](./dataGitlabMetadata.go.md)
- [dataGitlabProject](./dataGitlabProject.go.md)
- [dataGitlabProjectBranches](./dataGitlabProjectBranches.go.md)
- [dataGitlabProjectHook](./dataGitlabProjectHook.go.md)
- [dataGitlabProjectHooks](./dataGitlabProjectHooks.go.md)
- [dataGitlabProjectIssue](./dataGitlabProjectIssue.go.md)
- [dataGitlabProjectIssues](./dataGitlabProjectIssues.go.md)
- [dataGitlabProjectMembership](./dataGitlabProjectMembership.go.md)
- [dataGitlabProjectMilestone](./dataGitlabProjectMilestone.go.md)
- [dataGitlabProjectMilestones](./dataGitlabProjectMilestones.go.md)
- [dataGitlabProjectProtectedBranch](./dataGitlabProjectProtectedBranch.go.md)
- [dataGitlabProjectProtectedBranches](./dataGitlabProjectProtectedBranches.go.md)
- [dataGitlabProjectTag](./dataGitlabProjectTag.go.md)
- [dataGitlabProjectTags](./dataGitlabProjectTags.go.md)
- [dataGitlabProjectVariable](./dataGitlabProjectVariable.go.md)
- [dataGitlabProjectVariables](./dataGitlabProjectVariables.go.md)
- [dataGitlabProjects](./dataGitlabProjects.go.md)
- [dataGitlabReleaseLink](./dataGitlabReleaseLink.go.md)
- [dataGitlabReleaseLinks](./dataGitlabReleaseLinks.go.md)
- [dataGitlabRepositoryFile](./dataGitlabRepositoryFile.go.md)
- [dataGitlabRepositoryTree](./dataGitlabRepositoryTree.go.md)
- [dataGitlabUser](./dataGitlabUser.go.md)
- [dataGitlabUserSshkeys](./dataGitlabUserSshkeys.go.md)
- [dataGitlabUsers](./dataGitlabUsers.go.md)
- [deployKey](./deployKey.go.md)
- [deployKeyEnable](./deployKeyEnable.go.md)
- [deployToken](./deployToken.go.md)
- [group](./group.go.md)
- [groupAccessToken](./groupAccessToken.go.md)
- [groupBadge](./groupBadge.go.md)
- [groupCluster](./groupCluster.go.md)
- [groupCustomAttribute](./groupCustomAttribute.go.md)
- [groupHook](./groupHook.go.md)
- [groupLabel](./groupLabel.go.md)
- [groupLdapLink](./groupLdapLink.go.md)
- [groupMembership](./groupMembership.go.md)
- [groupProjectFileTemplate](./groupProjectFileTemplate.go.md)
- [groupSamlLink](./groupSamlLink.go.md)
- [groupShareGroup](./groupShareGroup.go.md)
- [groupVariable](./groupVariable.go.md)
- [instanceCluster](./instanceCluster.go.md)
- [instanceVariable](./instanceVariable.go.md)
- [label](./label.go.md)
- [managedLicense](./managedLicense.go.md)
- [pagesDomain](./pagesDomain.go.md)
- [personalAccessToken](./personalAccessToken.go.md)
- [pipelineSchedule](./pipelineSchedule.go.md)
- [pipelineScheduleVariable](./pipelineScheduleVariable.go.md)
- [pipelineTrigger](./pipelineTrigger.go.md)
- [project](./project.go.md)
- [projectAccessToken](./projectAccessToken.go.md)
- [projectApprovalRule](./projectApprovalRule.go.md)
- [projectBadge](./projectBadge.go.md)
- [projectCluster](./projectCluster.go.md)
- [projectCustomAttribute](./projectCustomAttribute.go.md)
- [projectEnvironment](./projectEnvironment.go.md)
- [projectFreezePeriod](./projectFreezePeriod.go.md)
- [projectHook](./projectHook.go.md)
- [projectIssue](./projectIssue.go.md)
- [projectIssueBoard](./projectIssueBoard.go.md)
- [projectLevelMrApprovals](./projectLevelMrApprovals.go.md)
- [projectMembership](./projectMembership.go.md)
- [projectMilestone](./projectMilestone.go.md)
- [projectMirror](./projectMirror.go.md)
- [projectProtectedEnvironment](./projectProtectedEnvironment.go.md)
- [projectRunnerEnablement](./projectRunnerEnablement.go.md)
- [projectShareGroup](./projectShareGroup.go.md)
- [projectTag](./projectTag.go.md)
- [projectVariable](./projectVariable.go.md)
- [provider](./provider.go.md)
- [releaseLink](./releaseLink.go.md)
- [repositoryFile](./repositoryFile.go.md)
- [runner](./runner.go.md)
- [serviceEmailsOnPush](./serviceEmailsOnPush.go.md)
- [serviceExternalWiki](./serviceExternalWiki.go.md)
- [serviceGithub](./serviceGithub.go.md)
- [serviceJira](./serviceJira.go.md)
- [serviceMicrosoftTeams](./serviceMicrosoftTeams.go.md)
- [servicePipelinesEmail](./servicePipelinesEmail.go.md)
- [serviceSlack](./serviceSlack.go.md)
- [systemHook](./systemHook.go.md)
- [tagProtection](./tagProtection.go.md)
- [topic](./topic.go.md)
- [user](./user.go.md)
- [userCustomAttribute](./userCustomAttribute.go.md)
- [userGpgkey](./userGpgkey.go.md)
- [userSshkey](./userSshkey.go.md)

==> cdktf-cdktf-provider-gitlab-6.0.2.tar.gz: package/docs/API.go.md <==
# Submodules <a name="Submodules" id="submodules"></a>

The following submodules are available:
- [application](./application.go.md)
- [applicationSettings](./applicationSettings.go.md)
- [branch](./branch.go.md)
- [branchProtection](./branchProtection.go.md)
- [clusterAgent](./clusterAgent.go.md)
- [clusterAgentToken](./clusterAgentToken.go.md)
- [dataGitlabApplication](./dataGitlabApplication.go.md)
- [dataGitlabBranch](./dataGitlabBranch.go.md)
- [dataGitlabClusterAgent](./dataGitlabClusterAgent.go.md)
- [dataGitlabClusterAgents](./dataGitlabClusterAgents.go.md)
- [dataGitlabCurrentUser](./dataGitlabCurrentUser.go.md)
- [dataGitlabGroup](./dataGitlabGroup.go.md)
- [dataGitlabGroupHook](./dataGitlabGroupHook.go.md)
- [dataGitlabGroupHooks](./dataGitlabGroupHooks.go.md)
- [dataGitlabGroupMembership](./dataGitlabGroupMembership.go.md)
- [dataGitlabGroupSubgroups](./dataGitlabGroupSubgroups.go.md)
- [dataGitlabGroupVariable](./dataGitlabGroupVariable.go.md)
- [dataGitlabGroupVariables](./dataGitlabGroupVariables.go.md)
- [dataGitlabGroups](./dataGitlabGroups.go.md)
- [dataGitlabInstanceDeployKeys](./dataGitlabInstanceDeployKeys.go.md)
- [dataGitlabInstanceVariable](./dataGitlabInstanceVariable.go.md)
- [dataGitlabInstanceVariables](./dataGitlabInstanceVariables.go.md)
- [dataGitlabMetadata](./dataGitlabMetadata.go.md)
- [dataGitlabProject](./dataGitlabProject.go.md)
- [dataGitlabProjectBranches](./dataGitlabProjectBranches.go.md)
- [dataGitlabProjectHook](./dataGitlabProjectHook.go.md)
- [dataGitlabProjectHooks](./dataGitlabProjectHooks.go.md)
- [dataGitlabProjectIssue](./dataGitlabProjectIssue.go.md)
- [dataGitlabProjectIssues](./dataGitlabProjectIssues.go.md)
- [dataGitlabProjectMembership](./dataGitlabProjectMembership.go.md)
- [dataGitlabProjectMilestone](./dataGitlabProjectMilestone.go.md)
- [dataGitlabProjectMilestones](./dataGitlabProjectMilestones.go.md)
- [dataGitlabProjectProtectedBranch](./dataGitlabProjectProtectedBranch.go.md)
- [dataGitlabProjectProtectedBranches](./dataGitlabProjectProtectedBranches.go.md)
- [dataGitlabProjectTag](./dataGitlabProjectTag.go.md)
- [dataGitlabProjectTags](./dataGitlabProjectTags.go.md)
- [dataGitlabProjectVariable](./dataGitlabProjectVariable.go.md)
- [dataGitlabProjectVariables](./dataGitlabProjectVariables.go.md)
- [dataGitlabProjects](./dataGitlabProjects.go.md)
- [dataGitlabReleaseLink](./dataGitlabReleaseLink.go.md)
- [dataGitlabReleaseLinks](./dataGitlabReleaseLinks.go.md)
- [dataGitlabRepositoryFile](./dataGitlabRepositoryFile.go.md)
- [dataGitlabRepositoryTree](./dataGitlabRepositoryTree.go.md)
- [dataGitlabUser](./dataGitlabUser.go.md)
- [dataGitlabUserSshkeys](./dataGitlabUserSshkeys.go.md)
- [dataGitlabUsers](./dataGitlabUsers.go.md)
- [deployKey](./deployKey.go.md)
- [deployKeyEnable](./deployKeyEnable.go.md)
- [deployToken](./deployToken.go.md)
- [group](./group.go.md)
- [groupAccessToken](./groupAccessToken.go.md)
- [groupBadge](./groupBadge.go.md)
- [groupCluster](./groupCluster.go.md)
- [groupCustomAttribute](./groupCustomAttribute.go.md)
- [groupHook](./groupHook.go.md)
- [groupLabel](./groupLabel.go.md)
- [groupLdapLink](./groupLdapLink.go.md)
- [groupMembership](./groupMembership.go.md)
- [groupProjectFileTemplate](./groupProjectFileTemplate.go.md)
- [groupSamlLink](./groupSamlLink.go.md)
- [groupShareGroup](./groupShareGroup.go.md)
- [groupVariable](./groupVariable.go.md)
- [instanceCluster](./instanceCluster.go.md)
- [instanceVariable](./instanceVariable.go.md)
- [label](./label.go.md)
- [managedLicense](./managedLicense.go.md)
- [pagesDomain](./pagesDomain.go.md)
- [personalAccessToken](./personalAccessToken.go.md)
- [pipelineSchedule](./pipelineSchedule.go.md)
- [pipelineScheduleVariable](./pipelineScheduleVariable.go.md)
- [pipelineTrigger](./pipelineTrigger.go.md)
- [project](./project.go.md)
- [projectAccessToken](./projectAccessToken.go.md)
- [projectApprovalRule](./projectApprovalRule.go.md)
- [projectBadge](./projectBadge.go.md)
- [projectCluster](./projectCluster.go.md)
- [projectCustomAttribute](./projectCustomAttribute.go.md)
- [projectEnvironment](./projectEnvironment.go.md)
- [projectFreezePeriod](./projectFreezePeriod.go.md)
- [projectHook](./projectHook.go.md)
- [projectIssue](./projectIssue.go.md)
- [projectIssueBoard](./projectIssueBoard.go.md)
- [projectLevelMrApprovals](./projectLevelMrApprovals.go.md)
- [projectMembership](./projectMembership.go.md)
- [projectMilestone](./projectMilestone.go.md)
- [projectMirror](./projectMirror.go.md)
- [projectProtectedEnvironment](./projectProtectedEnvironment.go.md)
- [projectRunnerEnablement](./projectRunnerEnablement.go.md)
- [projectShareGroup](./projectShareGroup.go.md)
- [projectTag](./projectTag.go.md)
- [projectVariable](./projectVariable.go.md)
- [provider](./provider.go.md)
- [releaseLink](./releaseLink.go.md)
- [repositoryFile](./repositoryFile.go.md)
- [runner](./runner.go.md)
- [serviceCustomIssueTracker](./serviceCustomIssueTracker.go.md)
- [serviceEmailsOnPush](./serviceEmailsOnPush.go.md)
- [serviceExternalWiki](./serviceExternalWiki.go.md)
- [serviceGithub](./serviceGithub.go.md)
- [serviceJira](./serviceJira.go.md)
- [serviceMicrosoftTeams](./serviceMicrosoftTeams.go.md)
- [servicePipelinesEmail](./servicePipelinesEmail.go.md)
- [serviceSlack](./serviceSlack.go.md)
- [systemHook](./systemHook.go.md)
- [tagProtection](./tagProtection.go.md)
- [topic](./topic.go.md)
- [user](./user.go.md)
- [userCustomAttribute](./userCustomAttribute.go.md)
- [userGpgkey](./userGpgkey.go.md)
- [userSshkey](./userSshkey.go.md)
